unit Misc;

{$A+,B+,E-,F-,G-,I-,P+,Q-,R-,S-,T-,V-,X+}

{ Miscellaneous functions/procedures that don't go anywhere else }

interface

type
    TFileType=(ftNotFound,ftFile,ftDirectory);

{ Determines whether a given filespec is a file or directory }
function GetFileType(const FileSpec:String):TFileType;

{ Returns true if given filespec is a relative path }
function IsRelativePath(const FileSpec:String):Boolean;

{ Drop trailing backslash off given path }
function DropTrailingBackslash(const FileSpec:String):String;

{ Applies a relative path to an absolute path }
{ AbsPath should be an absolute path, RelPath may be absolute/relative }
function AdjustRelativePath(const AbsPath,RelPath:String):String;

{ Returns path of given file specification, w/o trailing backslash }
function GetPathOf(const FileSpec:String):String;

{ Opens a text file read only w/ error checking, returns true if success }
function ResetWithErrorCheck(var F:Text;const FileName:String):Boolean;

{ Returns a range of command line arguments concatenated as one string,     }
{ seperated by spaces.                                                      }
function ParamStrRange(First,Last:Integer):String;

{ Converts a character to lowercase }
function LoCase(C:Char):Char;

{ Converts a string to uppercase }
function UpperCase(const S:String):String;

{ Converts a string to lowercase }
function LowerCase(const S:String):String;

implementation

uses Dos;

function GetFileType(const FileSpec:String):TFileType;
var
    Search:SearchRec;
begin
    FindFirst(FileSpec,ReadOnly+Hidden+SysFile+Directory+Archive,Search);
    if DosError=0 then
    begin
        if (Search.Attr and Directory)=Directory then GetFileType:=ftDirectory
            else GetFileType:=ftFile;
    end else begin
        DosError:=0;
        GetFileType:=ftNotFound;
    end
end;

function IsRelativePath(const FileSpec:String):Boolean;
begin
    if Length(FileSpec)>0 then
        IsRelativePath:=(Pos(':',FileSpec)=0) and (FileSpec[1]<>'\')
        else IsRelativePath:=True;
end;

function DropTrailingBackslash(const FileSpec:String):String;
begin
    if (Length(FileSpec)>0) and (FileSpec[Length(FileSpec)]='\') then
        DropTrailingBackslash:=Copy(FileSpec,1,Length(FileSpec)-1)
        else DropTrailingBackslash:=FileSpec;
end;

function AdjustRelativePath(const AbsPath,RelPath:String):String;
begin
    if IsRelativePath(RelPath) then
        AdjustRelativePath:=FExpand(DropTrailingBackslash(AbsPath)+'\'+RelPath)
        else AdjustRelativePath:=RelPath;
end;

function GetPathOf(const FileSpec:String):String;
var
    Dir:DirStr;
    Name:NameStr;
    Ext:ExtStr;
begin
    FSplit(FileSpec,Dir,Name,Ext);
    GetPathOf:=DropTrailingBackslash(Dir);
end;

function ResetWithErrorCheck(var F:Text;const FileName:String):Boolean;
begin
    FileMode:=0;
    Assign(F,FileName);
    Reset(F);
    ResetWithErrorCheck:=IOResult=0;
end;

function ParamStrRange(First,Last:Integer):String;
var
    S:String;
    Index:Integer;
begin
    S:='';
    if Last>ParamCount then Last:=ParamCount;
    if First<=ParamCount then
    begin
        S:=ParamStr(First);
        for Index:=First+1 to Last do S:=S+' '+ParamStr(Index);
    end;
    ParamStrRange:=S;
end;

function LoCase(C:Char):Char;
begin
    if C in ['A'..'Z'] then LoCase:=Chr(Ord(C)+32) else LoCase:=C;
end;

function UpperCase(const S:String):String;
var
    Result:String;
    I:Integer;
begin
    Result:=S;
    for I:=1 to Length(Result) do Result[I]:=UpCase(Result[I]);
    UpperCase:=Result;
end;

function LowerCase(const S:String):String;
var
    Result:String;
    I:Integer;
begin
    Result:=S;
    for I:=1 to Length(Result) do Result[I]:=LoCase(Result[I]);
    LowerCase:=Result;
end;


end.
